import { Span } from 'opentracing';
import { ConfService, DataRequest, InitConfigFork, ResponseMessage, ErrorMetadata } from './types';
import { HttpResponse } from './httpResponse';
/**
 * Clase base para los Worker y Fork
 */
export default abstract class Base {
    [x: string]: any;
    /**
     * Configuracion del servicio
     * @protected
     */
    protected config: ConfService;
    /**
     * Topico del servicio
     * @protected
     */
    protected Topic: string;
    /**
     * Opentracing Span
     * @protected
     */
    protected span: Span;
    /**
     * Contructor de la clase
     * @param conf Configuracion del servicio
     */
    constructor(conf: ConfService, topic: string, span: Span);
    /**
     * Metodo para dar formato a la metadata de http
     *
     * @param {DataRequest} data
     * @param {(any | HttpResponse)} resp
     * @returns {*}
     * @memberof Base
     */
    httpFormat(data: DataRequest, resp: any | HttpResponse): {
        request: DataRequest;
        data: any;
    };
    /**
     * Generador del formato de error
     *
     * @param {DataRequest} data
     * @param {*} error
     * @param {*} ff
     * @memberof Base
     */
    errorHandler(data: DataRequest, error: any, ff: any): void;
    /**
     * Metodo que hace rel registro de Forks
     * para su utilizacion sobre los servicios.
     * @param conf Configuracion para el evento
     */
    forksConfig(conf: InitConfigFork[]): void;
    /**
     * Metodo que procesa el mensaje del servicio.
     * @abstract
     * @param data Datos del mensaje
     */
    abstract message(data: DataRequest, Method: () => void, params: string[]): Promise<any>;
    transformFilters(filters: any): any;
    /**
     * Metodo para dar formato a los mensajes de salida.
     *
     * @param {DataRequest} Data Data que se pasa como resultado de la operacion
     * @param {*} response Respuesta
     * @param {number} errorCode Codigo del error al momento de la excepcion
     * @param {boolean} isForkError Indicador si el error proviene de una bifurcacion.
     * @param {ErrorMetadata} errorMeta Metadata del error de la bifurcacion.
     * @returns {ResponseMessage}
     * @memberof Base
     */
    formatResponse(Data: DataRequest, response: any, errorCode?: number, isForkError?: boolean, errorMeta?: ErrorMetadata): ResponseMessage;
}
